.. :changelog:

History
-------

0.0.1 (09-12-2017)
---------------------

* First code creation


3.0.2 (16-02-2019)
------------------

* Ported to the latest template. Fixed an issue with the monkey patched requests get method assuming no other process running. Refactored some code to 3.7 specific.


3.0.3 (16-02-2019)
------------------

* Small template cleanup
